@@ -21,6 +21,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <pthread.h>
 #include <string.h>
 #include <time.h>
@@ -1118,8 +1122,8 @@ mapi_folder_item_to_msg( CamelFolder *folder,
 
 			camel_mime_part_set_content_id (part, content_id);
 
-			/*Fall back to default*/
-			camel_mime_part_set_encoding (part, CAMEL_TRANSFER_ENCODING_BASE64);
+			/*FIXME : Mime Reader / Writer work*/
+			//camel_mime_part_set_encoding (part, CAMEL_TRANSFER_ENCODING_BASE64);
 
 			camel_multipart_add_part (multipart, part);
 			camel_object_unref (part);
@@ -1484,6 +1488,12 @@ mapi_transfer_messages_to (CamelFolder *source, GPtrArray *uids,
 	return;
 }
 
+static void
+mapi_folder_rename (CamelFolder *folder, const char *new)
+{
+	((CamelFolderClass *)parent_class)->rename(folder, new);
+}
+
 static void
 camel_mapi_folder_class_init (CamelMapiFolderClass *camel_mapi_folder_class)
 {
@@ -1494,7 +1504,7 @@ camel_mapi_folder_class_init (CamelMapiFolderClass *camel_mapi_folder_class)
 	((CamelObjectClass *) camel_mapi_folder_class)->getv = mapi_getv;
 
 	camel_folder_class->get_message = mapi_folder_get_message;
-/*  	camel_folder_class->rename = mapi_folder_rename; */
+ 	camel_folder_class->rename = mapi_folder_rename;
 	camel_folder_class->search_by_expression = mapi_folder_search_by_expression;
 /* 	camel_folder_class->get_message_info = mapi_get_message_info; */
 /* 	camel_folder_class->search_by_uids = mapi_folder_search_by_uids;  */
