@@ -58,7 +58,7 @@
 /* This definition should be in-sync with those in exchange-mapi-account-setup.c and exchange-account-listener.c */
 #define E_PASSWORD_COMPONENT "ExchangeMAPI"
 
-#define DISPLAY_NAME_FAVOURITES _("Favourites")
+#define DISPLAY_NAME_FAVOURITES _("Favorites")
 #define DISPLAY_NAME_ALL_PUBLIC_FOLDERS _("All Public Folders")
 
 #include <sys/types.h>
@@ -261,7 +261,7 @@ static char
 	if (brief) {
 		return g_strdup_printf(_("Exchange MAPI server %s"), service->url->host);
 	} else {
-		return g_strdup_printf(_("Exchange MAPI for %s on %s"),
+		return g_strdup_printf(_("Exchange MAPI service for %s on %s"),
 				       service->url->user, service->url->host);
 	}
 }
@@ -317,8 +317,7 @@ mapi_auth_loop (CamelService *service, CamelException *ex)
 		exchange_mapi_connection_new (NULL,service->url->passwd);
 
 		if (!exchange_mapi_connection_exists ()) {
-			errbuf = g_strdup_printf (_("Unable to authenticate "
-					    "to Exchange MAPI server. "));
+			errbuf = g_strdup_printf (_("Unable to authenticate to Exchange MAPI server."));
 						  
 			camel_exception_clear (ex);
 		} else 
@@ -402,7 +401,7 @@ mapi_fid_is_system_folder (CamelMapiStore *mapi_store, const char *fid)
 	if (!(fid && *fid)) 
 		return FALSE;
 
-	return (g_hash_table_find (priv->default_folders, hash_check_fid_presence, fid) != NULL);
+	return (g_hash_table_find (priv->default_folders, hash_check_fid_presence, (gpointer) fid) != NULL);
 }
 
 static const gchar*
@@ -502,18 +501,6 @@ mapi_forget_folder (CamelMapiStore *mapi_store, const char *folder_name, CamelEx
 		return;
 	}
 
-	summary_file = g_strdup_printf ("%s/summary", folder_dir);
-	summary = camel_mapi_summary_new(NULL,summary_file);
-	if(!summary) {
-		g_free(summary_file);
-		g_free(folder_dir);
-		return;
-	}
-
-	camel_object_unref (summary);
-	g_unlink (summary_file);
-	g_free (summary_file);
-
 	state_file = g_strdup_printf ("%s/cmeta", folder_dir);
 	g_unlink (state_file);
 	g_free (state_file);
@@ -639,6 +626,7 @@ mapi_rename_folder(CamelStore *store, const char *old_name, const char *new_name
 {
 	CamelMapiStore *mapi_store = CAMEL_MAPI_STORE (store);
 	CamelMapiStorePrivate  *priv = mapi_store->priv;
+	CamelStoreInfo *si = NULL;
 	char *oldpath, *newpath, *storepath;
 	const char *folder_id;
 	char *temp = NULL;
@@ -660,7 +648,8 @@ mapi_rename_folder(CamelStore *store, const char *old_name, const char *new_name
 
 	folder_id = camel_mapi_store_folder_id_lookup (mapi_store, temp);
 	if (!folder_id) {
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot rename MAPI folder `%s'. Folder doesn't exist"),
+		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, 
+				      _("Cannot rename MAPI folder `%s'. Folder does not exist."),
 				      old_name);
 		CAMEL_SERVICE_REC_UNLOCK (mapi_store, connect_lock);
 		return;
@@ -668,12 +657,12 @@ mapi_rename_folder(CamelStore *store, const char *old_name, const char *new_name
 
 	/*Do not allow rename for system folders.*/
 	if (mapi_fid_is_system_folder (mapi_store, folder_id)) {
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot rename Mapi folder `%s' to `%s'. Default folder."),
+		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, 
+				      _("Cannot rename MAPI folder `%s' to `%s'. Default folder."),
 				      old_name, new_name);
 		return;
 	}
 
-
 	exchange_mapi_util_mapi_id_from_string (folder_id, &fid);
 		
 	temp = strrchr (new_name, '/');
@@ -684,12 +673,15 @@ mapi_rename_folder(CamelStore *store, const char *old_name, const char *new_name
 	
 	if (!exchange_mapi_rename_folder (fid , temp))
 	{
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot rename MAPI folder `%s' to `%s'"),
-				      old_name, new_name);
+		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, 
+				      _("Cannot rename MAPI folder `%s' to `%s'"), old_name, new_name);
+
 		CAMEL_SERVICE_REC_UNLOCK (mapi_store, connect_lock);
 		return;
 	}
 
+	CAMEL_SERVICE_REC_UNLOCK (mapi_store, connect_lock);
+
 	g_hash_table_replace (priv->id_hash, g_strdup(folder_id), g_strdup(temp));
 
 	g_hash_table_insert (priv->name_hash, g_strdup(new_name), g_strdup(folder_id));
@@ -701,6 +693,17 @@ mapi_rename_folder(CamelStore *store, const char *old_name, const char *new_name
 	g_free (storepath);
 
 	/*XXX: make sure the summary is also renamed*/
+	si = camel_store_summary_path ((CamelStoreSummary *)mapi_store->summary, old_name);
+
+	if (si) {
+		camel_store_info_set_string((CamelStoreSummary *)mapi_store->summary, si,
+					    CAMEL_STORE_INFO_PATH, new_name);
+		camel_store_info_set_string((CamelStoreSummary *)mapi_store->summary, si,
+					    CAMEL_MAPI_STORE_INFO_FULL_NAME, new_name);
+
+		camel_store_summary_touch((CamelStoreSummary *)mapi_store->summary);
+	}
+
 	if (g_rename (oldpath, newpath) == -1) {
 		g_warning ("Could not rename message cache '%s' to '%s': %s: cache reset",
 				oldpath, newpath, strerror (errno));
@@ -708,7 +711,7 @@ mapi_rename_folder(CamelStore *store, const char *old_name, const char *new_name
 
 	g_free (oldpath);
 	g_free (newpath);
-	CAMEL_SERVICE_REC_UNLOCK (mapi_store, connect_lock);
+
 }
 
 static guint32 hexnib(guint32 c)
@@ -854,10 +857,11 @@ mapi_build_folder_info(CamelMapiStore *mapi_store, const char *parent_name, cons
 		fi->full_name = g_strdup(folder_name);
  
 	url = camel_url_new(priv->base_url,NULL);
-	//g_free(url->path);
+	g_free(url->path);
+
 	url->path = g_strdup_printf("/%s", fi->full_name);
 	fi->uri = camel_url_to_string(url,CAMEL_URL_HIDE_ALL);
-	//camel_url_free(url);
+	camel_url_free(url);
 
 	name = strrchr(fi->full_name,'/');
 	if(name == NULL)
@@ -920,9 +924,9 @@ mapi_get_folder_info_offline (CamelStore *store, const char *top,
 		if ( !strcmp(name, camel_mapi_store_info_full_name (mapi_store->summary, si))
 		     || match_path (path, camel_mapi_store_info_full_name (mapi_store->summary, si))) {
 
-			gchar *store_info_path = camel_store_info_path((CamelStoreSummary *)mapi_store->summary, si);
+			const gchar *store_info_path = camel_store_info_path((CamelStoreSummary *)mapi_store->summary, si);
 			gchar *parent_name = NULL;
-			gchar *folder_name = NULL;
+			const gchar *folder_name = NULL;
 
 			/* TODO : UTF8 / i18n*/
 			if (g_str_has_prefix (store_info_path, DISPLAY_NAME_ALL_PUBLIC_FOLDERS) && subscribed) {
@@ -953,7 +957,7 @@ mapi_get_folder_info_offline (CamelStore *store, const char *top,
 	}
 
 	/*FIXME*/
-	if (!((!subscribed) && info_fast) ) {
+	if (!((!subscribed) && info_fast) && top[0] == '\0') {
 		fi = mapi_build_folder_info(mapi_store, NULL, DISPLAY_NAME_FAVOURITES);
 		fi->flags |= CAMEL_FOLDER_NOSELECT;
 		fi->flags |= CAMEL_FOLDER_SYSTEM;
@@ -1156,7 +1160,7 @@ mapi_folders_sync (CamelMapiStore *store, CamelException *ex)
 			continue;
 
 		info = mapi_convert_to_folder_info (store, folder, (const char *)url, ex);
-		if (!(mapi_si = camel_store_summary_path ((CamelStoreSummary *)store->summary, info->full_name))){
+		if (!(mapi_si = (CamelMapiStoreInfo *) camel_store_summary_path ((CamelStoreSummary *)store->summary, info->full_name))){
 			mapi_si = camel_mapi_store_summary_add_from_full (store->summary, info->full_name, '/');
 			if (mapi_si == NULL) {
 				continue;
@@ -1254,13 +1258,14 @@ mapi_subscribe_folder(CamelStore *store, const char *folder_name, CamelException
 	CamelMapiStore *mapi_store = CAMEL_MAPI_STORE (store);
 
 	CamelFolderInfo *fi;
-	CamelStoreInfo *si;
+	CamelStoreInfo *si = NULL;
 	gchar *parent_name = NULL;
 	gchar *f_name = NULL;
 	CamelURL *url;
 	/* TODO : exchange_mapi_add_to_favorites (); */
 
-	if (si = camel_store_summary_path((CamelStoreSummary *)mapi_store->summary, folder_name)) {
+	si = camel_store_summary_path((CamelStoreSummary *)mapi_store->summary, folder_name);
+	if (si != NULL) {
 		if ((si->flags & CAMEL_STORE_INFO_FOLDER_SUBSCRIBED) == 0) {
 			si->flags |= CAMEL_STORE_INFO_FOLDER_SUBSCRIBED;
 			si->flags |= CAMEL_FOLDER_SUBSCRIBED;
@@ -1275,6 +1280,8 @@ mapi_subscribe_folder(CamelStore *store, const char *folder_name, CamelException
 		f_name = strrchr(folder_name,'/');
 		if(f_name != NULL)
 			folder_name = ++f_name;
+		else  //Don't process All Public Folder.
+			return;
 	}
 
 	fi = mapi_build_folder_info(mapi_store, parent_name, g_strdup (folder_name)); /* FIXME */
@@ -1332,6 +1339,8 @@ mapi_unsubscribe_folder(CamelStore *store, const char *folder_name, CamelExcepti
 		f_name = strrchr(folder_name,'/');
 		if(f_name != NULL)
 			folder_name = ++f_name;
+		else //Don't process All Public Folder.
+			return;
 	}
 
 	fi = mapi_build_folder_info(mapi_store, parent_name, g_strdup (folder_name)); /* FIXME */
